##  Custom Views
In addition to standard report views, you can create custom fact sheet fields and tag groups that can be applied as views in reports.
  * Custom fact sheet fields: Custom fields do not automatically appear in report views. To show a custom field in report views, in the fact sheet configuration, select a field, navigate to the Options tab in the sidebar indicated by the gear icon, enable the Include in views toggle, then save the changes. This option is only available for certain field types. For more information, see [Showing Fields in Views](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759fb817a44101492ded5b080b9f10c__showing_fields_in_views).
![Options Tab in the Field Configuration Sidebar on the Fact Sheet Configuration Page](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275566cb7a4410148631c8c87059126d_LowRes.png)
Options Tab in the Field Configuration Sidebar on the Fact Sheet Configuration Page
  * Tag groups: Non-empty tag groups of the Single mode automatically appear in report views. You can create more tag groups to show them in report views. For more information, see [Tagging](https://help.sap.com/docs/leanix/ea/tagging?locale=en-US&state=PRODUCTION&version=CLOUD "This guide covers the essential steps for managing tags, including creating tag groups, adding and editing tags within those groups, and deleting tags and tag groups. Suggest Edits Introduction").


To understand and customize aggregation methods in SAP LeanIX views and learn how the obsolescence risk view is aggregated based on IT component lifecycle statuses, see [Views Aggregation](https://help.sap.com/docs/leanix/ea/views-aggregation?locale=en-US&state=PRODUCTION&version=CLOUD "Understand and customize aggregation methods in SAP LeanIX views and learn how the obsolescence risk view is aggregated based on IT component lifecycle statuses.").
YesNo
Send
